@@ -1,4 +1,5 @@
-BchronRSL = function(BchronologyRun,RSLmean,RSLsd,degree=1,iterations=10000,burn=2000,thin=8) {
+BchronRSL <-
+function(BchronologyRun,RSLmean,RSLsd,degree=1,iterations=10000,burn=2000,thin=8) {
   if(degree>5) stop('Degree not supported')
   remaining=(iterations-burn)/thin
   betaStore = matrix(NA,ncol=degree+1,nrow=remaining)
@@ -27,4 +28,4 @@ BchronRSL = function(BchronologyRun,RSLmean,RSLsd,degree=1,iterations=10000,burn
   class(out) = 'BchronRSLRun'
   return(out)
   
-}
\ No newline at end of file
+}
